@@ -1,7 +1,9 @@
 """
-    Programming Problem Sites Utilities
+tests
+
+Some unit tests
 """
 
 __author__ = "Nayan Shah (nayan@nayanshah.com)"
 __copyright__ = "Copyright 2012, Nayan Shah"
-__license__ = "MIT License"
+__license__ = "MIT"
